{% extends "admin/change_list.html" %}
{% load i18n admin_static admin_list position_tags %}
{% load admin_urls %}


{% block result_list %}
    {% if action_form and actions_on_top and cl.full_result_count %}{% admin_actions %}{% endif %}
    {% position_result_list cl %}
    {% if action_form and actions_on_bottom and cl.full_result_count %}{% admin_actions %}{% endif %}
{% endblock %}