<!DOCTYPE html>
<html lang="en"><head>
<meta charset="UTF-8">
<title></title>
</head>
<body>
    {% block main %}{% endblock %}
    <script src="//ajax.googleapis.com/ajax/libs/jquery/1.9.1/jquery.min.js"></script>
    <script src="//ajax.googleapis.com/ajax/libs/jqueryui/1.10.2/jquery-ui.min.js"></script>
    {% block extrajs %}{% endblock %}
</body>
</html>